==> c360-input-checkbox-0.1.0.tgz: package/input-checkbox.js <==
/* Copyright (c) 2015-present, salesforce.com, inc. All rights reserved
  Licensed under BSD 3-Clause - see LICENSE.txt or git.io/sfdc-license */

import { fragmentFrom } from 'elix/src/core/htmlLiterals.js';
import { defaultState, template, state, setState, render } from 'elix/src/base/internal';
import SdsInputCheckbox from '@salesforce-ux/sds-input-checkbox/input-checkbox';
import css from './input-checkbox.css';

export default class C360InputCheckbox extends SdsInputCheckbox {
  get [defaultState]() {
    return Object.assign(super[defaultState], {
      size: 'default',
    });
  }

  get size() {
    return this[state].size;
  }

  set size(size) {
    this[setState]({
      size: size,
    });
  }

  [render](changed) {
    super[render](changed);
    if (changed.size) {
      const { size } = this[state];
      this.reflectAttribute(this, 'size', size);
    }
  }

  get [template]() {
    const result = super[template];
    this.appendHelpTextSlot(result);
    result.content.append(fragmentFrom.html`
        <style>
          ${css}
        </style>
      `);
    return result;
  }

  reflectAttribute(element, name, value) {
    if (value) {
      element.setAttribute(name, value);
    } else {
      element.removeAttribute(name);
    }
  }

  appendHelpTextSlot(result) {
    const helpTextSlot = result.content.querySelector('slot[name="help-text"]');
    const inputCheckbox = result.content.querySelector('[part="input-checkbox"]');
    if (!helpTextSlot && inputCheckbox) {
      inputCheckbox.insertAdjacentHTML('afterend', '<slot name="help-text"></slot>');
    }
  }
}

==> c360-input-checkbox-0.1.1.tgz: package/input-checkbox.js <==
/* Copyright (c) 2015-present, salesforce.com, inc. All rights reserved
  Licensed under BSD 3-Clause - see LICENSE.txt or git.io/sfdc-license */

import { fragmentFrom } from 'elix/src/core/htmlLiterals.js';
import { defaultState, template, state, setState, render } from 'elix/src/base/internal';
import SdsInputCheckbox from '@salesforce-ux/sds-input-checkbox/input-checkbox';
import { reflectAttribute } from '@salesforce-ux/sds-utils';
import css from './input-checkbox.css';

export default class C360InputCheckbox extends SdsInputCheckbox {
  get [defaultState]() {
    return Object.assign(super[defaultState], {
      size: 'default',
    });
  }

  get size() {
    return this[state].size;
  }

  set size(size) {
    this[setState]({
      size: size,
    });
  }

  [render](changed) {
    super[render](changed);
    if (changed.size) {
      const { size } = this[state];
      reflectAttribute(this, 'size', size);
    }
  }

  get [template]() {
    const result = super[template];
    this.appendHelpTextSlot(result);
    result.content.append(fragmentFrom.html`
        <style>
          ${css}
        </style>
      `);
    return result;
  }

  appendHelpTextSlot(result) {
    const helpTextSlot = result.content.querySelector('slot[name="help-text"]');
    const inputCheckbox = result.content.querySelector('[part="input-checkbox"]');
    if (!helpTextSlot && inputCheckbox) {
      inputCheckbox.insertAdjacentHTML('afterend', '<slot name="help-text"></slot>');
    }
  }
}
